#[repr(i32)]pub enum ConnectionStatus {
Unknown = 0,
Ready = 1,
Exited = 2,
Failed = 3,
}Expand description
Indicates the status of a connection.
Variants
Unknown = 0
Connection status is unknown.
Ready = 1
Connection was set up successfully. Server and client may now exchange messages.
Exited = 2
The server’s target program has exited. The server will immediately close the connection, and the client is expected to exit after its cleanup.
Failed = 3
A fatal error was encountered. The connection will be closed.
Implementations
Sourceimpl ConnectionStatus
impl ConnectionStatus
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ConnectionStatus.
Sourcepub fn from_i32(value: i32) -> Option<ConnectionStatus>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ConnectionStatus>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ConnectionStatus, or None if value is not a valid variant.
Sourceimpl ConnectionStatus
impl ConnectionStatus
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.