ConnectionStatusMessage

Struct ConnectionStatusMessage 

pub struct ConnectionStatusMessage {
    pub status: i32,
    pub description: String,
    pub code: i32,
}
A message that indicates to either the server or the client a change in connection status.

Fields

status: i32

New connection status. If the connection status is changed to anything except READY, the recipient must shut down.

description: String

Short description of any error that triggered the status change.

code: i32

Return code of the command, if any.

Implementations

Source

impl ConnectionStatusMessage

pub fn status(&self) -> ConnectionStatus

Returns the enum value of status, or the default if the field is set to an invalid enum value.

pub fn set_status(&mut self, value: ConnectionStatus)

Sets status to the provided enum value.